==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pl-PL/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'angielski (USA)',
        'en-GB'=> 'angielski (UK)',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'afrykanerski',
        'ar-SA'=> 'arabski',
        'bg-BG'=> 'bułgarski',
        'zh-CN'=> 'chiński uproszczony',
        'zh-TW'=> 'chiński tradycyjny',
        'ca-ES' => 'kataloński',
        'hr-HR'=> 'chorwacki',
        'cs-CZ'=> 'czeski',
        'da-DK'=> 'duński',
        'nl-NL'=> 'holenderski',
        'en-ID'=> 'angielski (Indonezja)',
        'et-EE'=> 'estoński',
        'fil-PH'=> 'filipiński',
        'fi-FI'=> 'fiński',
        'fr-FR'=> 'francuski',
        'de-DE'=> 'niemiecki',
        'de-if'=> 'niemiecki (nieoficjalny)',
        'el-GR'=> 'grecki',
        'he-IL'=> 'hebrajski',
        'hu-HU'=> 'węgierski',
        'is-IS' => 'islandzki',
        'id-ID'=> 'indonezyjski',
        'ga-IE'=> 'irlandzki',
        'it-IT'=> 'włoski',
        'ja-JP'=> 'japoński',
        'km-KH'=>'khmerski',
        'ko-KR'=> 'koreański',
        'lt-LT'=>'litewski',
        'lv-LV'=> 'łotewski',
        'mk-MK'=> 'macedoński',
        'ms-MY'=> 'malajski',
        'mi-NZ'=> 'maoryski',
        'mn-MN'=> 'mongolski',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'perski',
        'pl-PL'=> 'polski',
        'pt-PT'=> 'portugalski',
        'pt-BR'=> 'portugalski (brazylijski)',
        'ro-RO'=> 'rumuński',
        'ru-RU'=> 'rosyjski',
        'sr-CS' => 'serbski (łaciński)',
        'sk-SK'=> 'Słowacki',
        'sl-SI'=> 'słoweński',
        'so-SO'=> 'Somali',
        'es-ES'=> 'hiszpański',
        'es-CO'=> 'hiszpański, Kolumbia',
        'es-MX'=> 'hiszpański, Meksyk',
        'es-VE'=> 'hiszpański, Wenezuela',
        'sv-SE'=> 'szwedzki',
        'tl-PH'=> 'tagalog',
        'ta-IN'=> 'tamilski',
        'th-TH'=> 'tajski',
        'tr-TR'=> 'turecki',
        'uk-UA'=> 'ukraiński',
        'vi-VN'=> 'wietnamski',
        'cy-GB'=> 'walijski',
        'zu-ZA'=> 'zuluski',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Wyspa Wniebowstąpienia',
        'AD'=>'Andora',
        'AE'=>'Zjednoczone Emiraty Arabskie',
        'AF'=>'Afganistan',
        'AG'=>'Antigua i Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antyle Holenderskie',
        'AO'=>'Angola',
        'AQ'=>'Antarktyda',
        'AR'=>'Argentyna',
        'AS'=>'Amerykańskie Samoa',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Wyspy Alandzkie',
        'AZ'=>'Azerbejdżan',
        'BA'=>'Bośnia i Hercegowina',
        'BB'=>'Barbados',
        'BE'=>'Belgia',
        'BD'=>'Bangladesz',
        'BF'=>'Burkina Faso',
        'BG'=>'Bułgaria',
        'BH'=>'Bahrajn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermudy',
        'BN'=>'Republika Brunei',
        'BO'=>'Boliwia',
        'BR'=>'Brazylia',
        'BS'=>'Wyspy Bahama',
        'BT'=>'Bhutan',
        'BV'=>'Wyspa Bouveta',
        'BW'=>'Botswana',
        'BY'=>'Białoruś',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Wyspy Kokosowe (Wyspy Keelinga)',
        'CD'=>'Kongo (Republika Demokratyczna)',
        'CF'=>'Republika Środkowoafrykańska',
        'CG'=>'Kongo (Republika)',
        'CH'=>'Szwajcaria',
        'CI'=>'Wybrzeże Kości Słoniowej',
        'CK'=>'Wyspy Cooka',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Chińska Republika Ludowa',
        'CO'=>'Kolumbia',
        'CR'=>'Kostaryka',
        'CU'=>'Kuba',
        'CV'=>'Republika Zielonego Przylądka',
        'CX'=>'Wyspa Bożego Narodzenia',
        'CY'=>'Cypr',
        'CZ'=>'Republika Czeska',
        'DE'=>'Niemcy',
        'DJ'=>'Dżibuti',
        'DK'=>'Dania',
        'DM'=>'Dominika',
        'DO'=>'Dominikana',
        'DZ'=>'Algieria',
        'EC'=>'Ekwador',
        'EE'=>'Estonia',
        'EG'=>'Egipt',
        'GB-ENG'=>'England',
        'ER'=>'Erytrea',
        'ES'=>'Hiszpania',
        'ET'=>'Etiopia',
        'EU'=>'Unia Europejska',
        'FI'=>'Finlandia',
        'FJ'=>'Fidżi',
        'FK'=>'Falklandy (Malwiny)',
        'FM'=>'Sfederowane Stany Mikronezji',
        'FO'=>'Wyspy Owcze',
        'FR'=>'Francja',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gruzja',
        'GF'=>'Gujana Francuska',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grenlandia',
        'GM'=>'Gambia',
        'GN'=>'Gwinea',
        'GP'=>'Gwadelupa',
        'GQ'=>'Gwinea Równikowa',
        'GR'=>'Grecja',
        'GS'=>'Georgia Południowa i Sandwich Południowy',
        'GT'=>'Gwatemala',
        'GU'=>'Guam',
        'GW'=>'Gwinea-Bissau',
        'GY'=>'Gujana',
        'HK'=>'Hong Kong',
        'HM'=>'Wyspy Heard i McDonalda',
        'HN'=>'Honduras',
        'HR'=>'Chorwacja',
        'HT'=>'Haiti',
        'HU'=>'Węgry',
        'ID'=>'Indonezja',
        'IE'=>'Irlandia',
        'IL'=>'Izrael',
        'IM'=>'Wyspa Man',
        'IN'=>'Indie',
        'IO'=>'Brytyjskie Terytorium Oceanu Indyjskiego',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Islandia',
        'IT'=>'Włochy',
        'JE'=>'Jersey',
        'JM'=>'Jamajka',
        'JO'=>'Jordania',
        'JP'=>'Japonia',
        'KE'=>'Kenia',
        'KG'=>'Kirgistan',
        'KH'=>'Kambodża',
        'KI'=>'Kiribati',
        'KM'=>'Komory',
        'KN'=>'Saint Kitts i Nevis',
        'KR'=>'Korea Południowa',
        'KW'=>'Kuwejt',
        'KY'=>'Kajmany',
        'KZ'=>'Kazachstan',
        'LA'=>'Laos',
        'LB'=>'Liban',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litwa',
        'LU'=>'Luksemburg',
        'LV'=>'Łotwa',
        'LY'=>'Libia',
        'MA'=>'Maroko',
        'MC'=>'Monako',
        'MD'=>'Mołdawia, Republika',
        'ME'=>'Czarnogóra',
        'MG'=>'Madagaskar',
        'MH'=>'Wyspy Marshalla',
        'MK'=>'Macedonia Północna',
        'ML'=>'Mali',
        'MM'=>'Mjanma',
        'MN'=>'Mongolia',
        'MO'=>'Makau',
        'MP'=>'Mariany Północne',
        'MQ'=>'Martynika',
        'MR'=>'Mauretania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Malediwy',
        'MW'=>'Malawi',
        'MX'=>'Meksyk',
        'MY'=>'Malezja',
        'MZ'=>'Mozambik',
        'NA'=>'Namibia',
        'NC'=>'Nowa Kaledonia',
        'NE'=>'Niger',
        'NF'=>'Wyspa Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nikaragua',
        'NL'=>'Holandia',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norwegia',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nowa Zelandia',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Polinezja Francuska',
        'PG'=>'Papua Nowa Gwinea',
        'PH'=>'Filipiny',
        'PK'=>'Pakistan',
        'PL'=>'Polska',
        'PM'=>'Saint-Pierre i Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Portoryko',
        'PS'=>'Palestyna',
        'PT'=>'Portugalia',
        'PW'=>'Palau',
        'PY'=>'Paragwaj',
        'QA'=>'Katar',
        'RE'=>'Reunion',
        'RO'=>'Rumunia',
        'RS'=>'Serbia',
        'RU'=>'Federacja Rosyjska',
        'RW'=>'Rwanda',
        'SA'=>'Arabia Saudyjska',
        'GB-SCT'=>'Szkocja',
        'SB'=>'Wyspy Salomona',
        'SC'=>'Seszele',
        'SS'=>'Sudan Południowy',
        'SD'=>'Sudan',
        'SE'=>'Szwecja',
        'SG'=>'Singapur',
        'SH'=>'Wyspa Świętej Heleny',
        'SI'=>'Słowenia',
        'SJ'=>'Wyspy Svalbard i Jan Mayen',
        'SK'=>'Słowacja',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Wyspy Świętego Tomasza i Książęca',
        'SU'=>'Związek Radziecki',
        'SV'=>'Salwador',
        'SY'=>'Syria',
        'SZ'=>'Suazi',
        'TC'=>'Turks i Caicos',
        'TD'=>'Czad',
        'TF'=>'Francuskie Terytoria Południowe',
        'TG'=>'Togo',
        'TH'=>'Tajlandia',
        'TJ'=>'Tadżykistan',
        'TK'=>'Tokelau',
        'TI'=>'Timor Wschodni',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunezja',
        'TO'=>'Tonga',
        'TP'=>'Timor Wschodni (stary kod)',
        'TR'=>'Turcja',
        'TT'=>'Trynidad i Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tajwan',
        'TZ'=>'Tanzania',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Wielka Brytania',
        'US'=>'Stany Zjednoczone',
        'UM'=>'Dalekie Wyspy Mniejsze Stanów Zjednoczonych',
        'UY'=>'Urugwaj',
        'UZ'=>'Uzbekistan',
        'VA'=>'Watykan',
        'VC'=>'Saint Vincent i Grenadyny',
        'VE'=>'Wenezuela',
        'VG'=>'Brytyjskie Wyspy Dziewicze',
        'VI'=>'Wyspy Dziewicze Stanów Zjednoczonych',
        'VN'=>'Wietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis i Futuna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Majotta',
        'ZA'=>'Republika Południowej Afryki',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/pl-PL/localizations.php <==
<?php

return [

    'select_language' => 'Wybierz język',
    'languages' => [
        'en-US'=> 'angielski (USA)',
        'en-GB'=> 'angielski (UK)',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'afrykanerski',
        'ar-SA'=> 'arabski',
        'bg-BG'=> 'bułgarski',
        'zh-CN'=> 'chiński uproszczony',
        'zh-TW'=> 'chiński tradycyjny',
        'ca-ES' => 'kataloński',
        'hr-HR'=> 'chorwacki',
        'cs-CZ'=> 'czeski',
        'da-DK'=> 'duński',
        'nl-NL'=> 'holenderski',
        'en-ID'=> 'angielski (Indonezja)',
        'et-EE'=> 'estoński',
        'fil-PH'=> 'filipiński',
        'fi-FI'=> 'fiński',
        'fr-FR'=> 'francuski',
        'de-DE'=> 'niemiecki',
        'de-if'=> 'niemiecki (nieoficjalny)',
        'el-GR'=> 'grecki',
        'he-IL'=> 'hebrajski',
        'hu-HU'=> 'węgierski',
        'is-IS' => 'islandzki',
        'id-ID'=> 'indonezyjski',
        'ga-IE'=> 'irlandzki',
        'it-IT'=> 'włoski',
        'ja-JP'=> 'japoński',
        'km-KH'=>'khmerski',
        'ko-KR'=> 'koreański',
        'lt-LT'=>'litewski',
        'lv-LV'=> 'łotewski',
        'mk-MK'=> 'macedoński',
        'ms-MY'=> 'malajski',
        'mi-NZ'=> 'maoryski',
        'mn-MN'=> 'mongolski',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norweski',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'perski',
        'pl-PL'=> 'polski',
        'pt-PT'=> 'portugalski',
        'pt-BR'=> 'portugalski (brazylijski)',
        'ro-RO'=> 'rumuński',
        'ru-RU'=> 'rosyjski',
        'sr-CS' => 'serbski (łaciński)',
        'sk-SK'=> 'Słowacki',
        'sl-SI'=> 'słoweński',
        'so-SO'=> 'Somali',
        'es-ES'=> 'hiszpański',
        'es-CO'=> 'hiszpański, Kolumbia',
        'es-MX'=> 'hiszpański, Meksyk',
        'es-VE'=> 'hiszpański, Wenezuela',
        'sv-SE'=> 'szwedzki',
        'tl-PH'=> 'tagalog',
        'ta-IN'=> 'tamilski',
        'th-TH'=> 'tajski',
        'tr-TR'=> 'turecki',
        'uk-UA'=> 'ukraiński',
        'vi-VN'=> 'wietnamski',
        'cy-GB'=> 'walijski',
        'zu-ZA'=> 'zuluski',
    ],

    'select_country' => 'Wybierz kraj',
    
    'countries' => [
        'AC'=>'Wyspa Wniebowstąpienia',
        'AD'=>'Andora',
        'AE'=>'Zjednoczone Emiraty Arabskie',
        'AF'=>'Afganistan',
        'AG'=>'Antigua i Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antyle Holenderskie',
        'AO'=>'Angola',
        'AQ'=>'Antarktyda',
        'AR'=>'Argentyna',
        'AS'=>'Amerykańskie Samoa',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Wyspy Alandzkie',
        'AZ'=>'Azerbejdżan',
        'BA'=>'Bośnia i Hercegowina',
        'BB'=>'Barbados',
        'BE'=>'Belgia',
        'BD'=>'Bangladesz',
        'BF'=>'Burkina Faso',
        'BG'=>'Bułgaria',
        'BH'=>'Bahrajn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermudy',
        'BN'=>'Republika Brunei',
        'BO'=>'Boliwia',
        'BR'=>'Brazylia',
        'BS'=>'Wyspy Bahama',
        'BT'=>'Bhutan',
        'BV'=>'Wyspa Bouveta',
        'BW'=>'Botswana',
        'BY'=>'Białoruś',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Wyspy Kokosowe (Wyspy Keelinga)',
        'CD'=>'Kongo (Republika Demokratyczna)',
        'CF'=>'Republika Środkowoafrykańska',
        'CG'=>'Kongo (Republika)',
        'CH'=>'Szwajcaria',
        'CI'=>'Wybrzeże Kości Słoniowej',
        'CK'=>'Wyspy Cooka',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Chińska Republika Ludowa',
        'CO'=>'Kolumbia',
        'CR'=>'Kostaryka',
        'CU'=>'Kuba',
        'CV'=>'Republika Zielonego Przylądka',
        'CX'=>'Wyspa Bożego Narodzenia',
        'CY'=>'Cypr',
        'CZ'=>'Republika Czeska',
        'DE'=>'Niemcy',
        'DJ'=>'Dżibuti',
        'DK'=>'Dania',
        'DM'=>'Dominika',
        'DO'=>'Dominikana',
        'DZ'=>'Algieria',
        'EC'=>'Ekwador',
        'EE'=>'Estonia',
        'EG'=>'Egipt',
        'GB-ENG'=>'Anglia',
        'ER'=>'Erytrea',
        'ES'=>'Hiszpania',
        'ET'=>'Etiopia',
        'EU'=>'Unia Europejska',
        'FI'=>'Finlandia',
        'FJ'=>'Fidżi',
        'FK'=>'Falklandy (Malwiny)',
        'FM'=>'Sfederowane Stany Mikronezji',
        'FO'=>'Wyspy Owcze',
        'FR'=>'Francja',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gruzja',
        'GF'=>'Gujana Francuska',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grenlandia',
        'GM'=>'Gambia',
        'GN'=>'Gwinea',
        'GP'=>'Gwadelupa',
        'GQ'=>'Gwinea Równikowa',
        'GR'=>'Grecja',
        'GS'=>'Georgia Południowa i Sandwich Południowy',
        'GT'=>'Gwatemala',
        'GU'=>'Guam',
        'GW'=>'Gwinea-Bissau',
        'GY'=>'Gujana',
        'HK'=>'Hong Kong',
        'HM'=>'Wyspy Heard i McDonalda',
        'HN'=>'Honduras',
        'HR'=>'Chorwacja',
        'HT'=>'Haiti',
        'HU'=>'Węgry',
        'ID'=>'Indonezja',
        'IE'=>'Irlandia',
        'IL'=>'Izrael',
        'IM'=>'Wyspa Man',
        'IN'=>'Indie',
        'IO'=>'Brytyjskie Terytorium Oceanu Indyjskiego',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Islandia',
        'IT'=>'Włochy',
        'JE'=>'Jersey',
        'JM'=>'Jamajka',
        'JO'=>'Jordania',
        'JP'=>'Japonia',
        'KE'=>'Kenia',
        'KG'=>'Kirgistan',
        'KH'=>'Kambodża',
        'KI'=>'Kiribati',
        'KM'=>'Komory',
        'KN'=>'Saint Kitts i Nevis',
        'KR'=>'Korea Południowa',
        'KW'=>'Kuwejt',
        'KY'=>'Kajmany',
        'KZ'=>'Kazachstan',
        'LA'=>'Laos',
        'LB'=>'Liban',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litwa',
        'LU'=>'Luksemburg',
        'LV'=>'Łotwa',
        'LY'=>'Libia',
        'MA'=>'Maroko',
        'MC'=>'Monako',
        'MD'=>'Mołdawia, Republika',
        'ME'=>'Czarnogóra',
        'MG'=>'Madagaskar',
        'MH'=>'Wyspy Marshalla',
        'MK'=>'Macedonia Północna',
        'ML'=>'Mali',
        'MM'=>'Mjanma',
        'MN'=>'Mongolia',
        'MO'=>'Makau',
        'MP'=>'Mariany Północne',
        'MQ'=>'Martynika',
        'MR'=>'Mauretania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Malediwy',
        'MW'=>'Malawi',
        'MX'=>'Meksyk',
        'MY'=>'Malezja',
        'MZ'=>'Mozambik',
        'NA'=>'Namibia',
        'NC'=>'Nowa Kaledonia',
        'NE'=>'Niger',
        'NF'=>'Wyspa Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nikaragua',
        'NL'=>'Holandia',
        'GB-NIR' => 'Irlandia Północna',
        'NO'=>'Norwegia',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nowa Zelandia',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Polinezja Francuska',
        'PG'=>'Papua Nowa Gwinea',
        'PH'=>'Filipiny',
        'PK'=>'Pakistan',
        'PL'=>'Polska',
        'PM'=>'Saint-Pierre i Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Portoryko',
        'PS'=>'Palestyna',
        'PT'=>'Portugalia',
        'PW'=>'Palau',
        'PY'=>'Paragwaj',
        'QA'=>'Katar',
        'RE'=>'Reunion',
        'RO'=>'Rumunia',
        'RS'=>'Serbia',
        'RU'=>'Federacja Rosyjska',
        'RW'=>'Rwanda',
        'SA'=>'Arabia Saudyjska',
        'GB-SCT'=>'Szkocja',
        'SB'=>'Wyspy Salomona',
        'SC'=>'Seszele',
        'SS'=>'Sudan Południowy',
        'SD'=>'Sudan',
        'SE'=>'Szwecja',
        'SG'=>'Singapur',
        'SH'=>'Wyspa Świętej Heleny',
        'SI'=>'Słowenia',
        'SJ'=>'Wyspy Svalbard i Jan Mayen',
        'SK'=>'Słowacja',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Wyspy Świętego Tomasza i Książęca',
        'SU'=>'Związek Radziecki',
        'SV'=>'Salwador',
        'SY'=>'Syria',
        'SZ'=>'Suazi',
        'TC'=>'Turks i Caicos',
        'TD'=>'Czad',
        'TF'=>'Francuskie Terytoria Południowe',
        'TG'=>'Togo',
        'TH'=>'Tajlandia',
        'TJ'=>'Tadżykistan',
        'TK'=>'Tokelau',
        'TI'=>'Timor Wschodni',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunezja',
        'TO'=>'Tonga',
        'TP'=>'Timor Wschodni (stary kod)',
        'TR'=>'Turcja',
        'TT'=>'Trynidad i Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tajwan',
        'TZ'=>'Tanzania',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Wielka Brytania',
        'US'=>'Stany Zjednoczone',
        'UM'=>'Dalekie Wyspy Mniejsze Stanów Zjednoczonych',
        'UY'=>'Urugwaj',
        'UZ'=>'Uzbekistan',
        'VA'=>'Watykan',
        'VC'=>'Saint Vincent i Grenadyny',
        'VE'=>'Wenezuela',
        'VG'=>'Brytyjskie Wyspy Dziewicze',
        'VI'=>'Wyspy Dziewicze Stanów Zjednoczonych',
        'VN'=>'Wietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Walia',
        'WF'=>'Wallis i Futuna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Majotta',
        'ZA'=>'Republika Południowej Afryki',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
